.. _ReferencePage:

=============
API Reference
=============

.. sectnum:: :start: 3


See :ref:`Usage` for how to use these functions for common tasks.

qe -- Quadratic Estimators
==========================

.. automodule:: symlens.qe
   :members:    


factorize -- Core utilties for factorization and integration
============================================================

.. automodule:: symlens.factorize
   :members:    

utils - General utilities
=========================

.. automodule:: symlens.utils
   :members:    
   
